@@ -3,7 +3,7 @@ context("exportTab")
 m <- createMassSpectrum(mass=1:5, intensity=6:10)
 r <- data.frame(V1=1:5, V2=6:10)
 
-test_that("exportTab", {
+test_that(".exportTab", {
   temp <- tempfile()
   MALDIquantForeign:::.exportTab(m, file=temp)
   ## didn't work on win-builder.r-project.org
@@ -13,7 +13,13 @@ test_that("exportTab", {
   expect_equal(read.table(temp), r)
 })
 
-test_that("exportCsv", {
+test_that("exportTab,MassSpectrum", {
+  temp <- tempfile()
+  MALDIquantForeign::exportTab(m, file=temp)
+  expect_equal(read.table(temp), r)
+})
+
+test_that(".exportCsv", {
   temp <- tempfile()
   MALDIquantForeign:::.exportCsv(m, file=temp)
   ## didn't work on win-builder.r-project.org
@@ -23,3 +29,10 @@ test_that("exportCsv", {
   colnames(r) <- c("mass", "intensity")
   expect_equal(read.csv(temp), r)
 })
+
+test_that("exportCsv,MassSpectrum", {
+  temp <- tempfile()
+  MALDIquantForeign::exportCsv(m, file=temp)
+  colnames(r) <- c("mass", "intensity")
+  expect_equal(read.csv(temp), r)
+})
